==> tine20-allinone_2020.03.4.tar.bz2: Tasks/js/Tasks-lang-de-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 12:25+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: de\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "GENDER_Task, GENDER_Tasks"
: [
  ""
 ,""

]
, "Task, Tasks"
: [
  "Aufgabe"
 ,"Aufgaben"

]
, "Percent"
: "Prozent"

, "Completed"
: "Abgeschlossen"

, "Due"
: "Fälligkeit"

, "Class"
: ""

, "Description"
: "Beschreibung"

, "Geo"
: ""

, "Location"
: ""

, "Organizer"
: "Organisator"

, "Priority"
: "Priorität"

, "Status, Status"
: [
  "Status"
 ,"Status"

]
, "Lead"
: "Lead"

, "Telephone"
: "Telefon"

, "Email"
: "Email"

, "Add New Task"
: "Neue Aufgabe hinzufügen"

, "You have to supply a due date, because an alarm ist set!"
: "Sie müssen ein Fälligkeitsdatum angeben, da ein Alarm gesetzt wurde!"

, "Summary"
: "Beschreibung"

, "Due date"
: "Fälligkeitsdatum"

, "Add Responsible ..."
: "Verantwortlichen hinzufügen ..."

, "Notes"
: "Anmerkungen"

, "Enter description..."
: "Beschreibung eingeben..."

, "Percentage"
: "Prozent"

, "Tasks"
: "Aufgaben"

, "to do list, to do lists"
: [
  "Aufgabenliste"
 ,"Aufgabenlisten"

]
, "to do lists"
: "Aufgabenlisten"

, "Quick Search"
: "Schnellsuche"

, "Due Date"
: "Fällig am"

, "Responsible"
: "Verantwortlich"

, "Last Modified Time"
: "Zuletzt geändert"

, "Last Modified By"
: "Zuletzt geändert von"

, "Creation Time"
: "Angelegt am"

, "Created By"
: "Angelegt von"

, "New Task"
: "Neue Aufgabe"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Wollen Sie die ausgewählte Aufgabe wirklich löschen?"
 ,"Wollen Sie die ausgewählten Aufgaben wirklich löschen?"

]
, "Attachments"
: ""

, "Tags"
: "Tags"

, "Lead name"
: "Leadname"

, "Add a task..."
: "Aufgabe hinzufügen..."

, "All my tasks"
: "Alle meine Aufgaben"

, "Default Favorite"
: "Standard Favorit"

, "The default favorite which is loaded on Tasks startup"
: "Der Standart Favorit der beim öffnen der Aufgabenlisten geladen wird"

, "Default Task List"
: "Standard-Aufgabenliste"

, "The default task list to create new tasks in."
: "Die Standard-Aufgabenliste, in der neue Aufgaben angelegt werden."

, "Tasks status available"
: "Verfügbare Taskstatus"

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: "Verfügbare Aufgabenstatus. Bitte beachten Sie, dass zusätzliche Werte beim Export oder der Synchronisation mit anderen Systemen nicht berücksichtigt werden könnten."

, "No response"
: "Keine Antwort"

, "Cancelled"
: "Abgebrochen"

, "In process"
: "Laufend"

, "Task priorities available"
: "Verfügbare Aufgabenprioritäten"

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: "Verfügbare Aufgabenprioritäten. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."

, "low"
: "niedrig"

, "normal"
: "normal"

, "high"
: "hoch"

, "urgent"
: "dringend"

, "manage shared task lists"
: "Gemeinsame Aufgabenlisten verwalten"

, "Create new shared tasks lists"
: "Neue gemeinse Aufgabenliste anlegen"

, "manage shared tasks favorites"
: "Gemeinsame Aufgaben-Favoriten verwalten"

, "Create or update shared tasks favorites"
: "Gemeinsame Aufgaben-Favoriten erstellen oder bearbeiten"

, "%s's personal tasks"
: "%ss persönliche Aufgaben"

, "Notification for Task %1$s"
: "Benachrichtigung für Aufgabe %1$s"

, "All tasks of my taskslists"
: "Alle Aufgaben auf meinen Aufgabenlisten"

, "My open tasks"
: "Offene Aufgaben für mich"

, "My open tasks this week"
: "Offene Aufgaben für mich (diese Woche)"

, "All tasks for me"
: "Alle Aufgaben für mich"

, "All tasks that I am responsible for"
: "Alle Aufgaben, für die ich verantwortlich bin"

, "Last modified by me"
: "Zuletzt von mir bearbeitet"

, "All tasks that I have last modified"
: "Alle Aufgaben, die ich zuletzt bearbeitet habe"

, "Tasks without responsible"
: "Aufgaben ohne Verantwortlichen"

, "Enable Standard Alarm"
: "Standardalarm"

, "New task get a standard alarm as defined below"
: "Neue Aufgaben bekommen einen Standardalarm wie unten definiert"

, "Minutes before the task ends"
: "Minuten bevor die Aufgabe endet"

, "Standard Alarm Time"
: "Standardalarmzeit"
, "GENDER_Task"
: ""

, "Task"
: "Aufgabe"

, "Status"
: "Status"

, "to do list"
: "Aufgabenliste"

, "Do you really want to delete the selected task?"
: "Wollen Sie die ausgewählte Aufgabe wirklich löschen?"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Tasks/js/Tasks-lang-de-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 12:25+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nLanguage: de\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Add New Task"
: "Neue Aufgabe hinzufügen"

, "You have to supply a due date, because an alarm ist set!"
: "Sie müssen ein Fälligkeitsdatum angeben, da ein Alarm gesetzt wurde!"

, "Summary"
: "Beschreibung"

, "Due date"
: "Fälligkeitsdatum"

, "Priority"
: "Priorität"

, "Organizer"
: "Organisator"

, "Add Responsible ..."
: "Verantwortlichen hinzufügen ..."

, "Notes"
: "Anmerkungen"

, "Enter description..."
: "Beschreibung eingeben..."

, "Percentage"
: "Prozent"

, "Status, Status"
: [
  "Status"
 ,"Status"

]
, "Completed"
: "Abgeschlossen"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Wollen Sie die ausgewählte Aufgabe wirklich löschen?"
 ,"Wollen Sie die ausgewählten Aufgaben wirklich löschen?"

]
, "Attachments"
: ""

, "Tags"
: "Tags"

, "Lead name"
: "Leadname"

, "Add a task..."
: "Aufgabe hinzufügen..."

, "Due Date"
: "Fällig am"

, "Percent"
: "Prozent"

, "Responsible"
: "Verantwortlich"

, "Task, Tasks"
: [
  "Aufgabe"
 ,"Aufgaben"

]
, "Tasks"
: "Aufgaben"

, "to do list, to do lists"
: [
  "Aufgabenliste"
 ,"Aufgabenlisten"

]
, "to do lists"
: "Aufgabenlisten"

, "Quick Search"
: "Schnellsuche"

, "Last Modified Time"
: "Zuletzt geändert"

, "Last Modified By"
: "Zuletzt geändert von"

, "Creation Time"
: "Angelegt am"

, "Created By"
: "Angelegt von"

, "New Task"
: "Neue Aufgabe"

, "All my tasks"
: "Alle meine Aufgaben"

, "Default Favorite"
: "Standard Favorit"

, "The default favorite which is loaded on Tasks startup"
: "Der Standart Favorit der beim öffnen der Aufgabenlisten geladen wird"

, "Default Task List"
: "Standard-Aufgabenliste"

, "The default task list to create new tasks in."
: "Die Standard-Aufgabenliste, in der neue Aufgaben angelegt werden."

, "Enable Standard Alarm"
: "Standardalarm"

, "New task get a standard alarm as defined below"
: "Neue Aufgaben bekommen einen Standardalarm wie unten definiert"

, "Standard Alarm Time"
: "Standardalarmzeit"

, "Minutes before the task ends"
: "Minuten bevor die Aufgabe endet"

, "Tasks status available"
: "Verfügbare Taskstatus"

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: "Verfügbare Aufgabenstatus. Bitte beachten Sie, dass zusätzliche Werte beim Export oder der Synchronisation mit anderen Systemen nicht berücksichtigt werden könnten."

, "No response"
: "Keine Antwort"

, "Cancelled"
: "Abgebrochen"

, "In process"
: "Laufend"

, "Task priorities available"
: "Verfügbare Aufgabenprioritäten"

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: "Verfügbare Aufgabenprioritäten. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."

, "low"
: "niedrig"

, "normal"
: "normal"

, "high"
: "hoch"

, "urgent"
: "dringend"

, "%s's personal tasks"
: "%ss persönliche Aufgaben"

, "GENDER_Task"
: ""

, "Due"
: "Fälligkeit"

, "Class"
: ""

, "Description"
: "Beschreibung"

, "Geo"
: ""

, "Location"
: ""

, "Lead"
: "Lead"

, "Telephone"
: "Telefon"

, "Email"
: "Email"

, "Notification for Task %1$s"
: "Benachrichtigung für Aufgabe %1$s"

, "All tasks of my taskslists"
: "Alle Aufgaben auf meinen Aufgabenlisten"

, "My open tasks"
: "Offene Aufgaben für mich"

, "My open tasks this week"
: "Offene Aufgaben für mich (diese Woche)"

, "All tasks for me"
: "Alle Aufgaben für mich"

, "All tasks that I am responsible for"
: "Alle Aufgaben, für die ich verantwortlich bin"

, "Last modified by me"
: "Zuletzt von mir bearbeitet"

, "All tasks that I have last modified"
: "Alle Aufgaben, die ich zuletzt bearbeitet habe"

, "Tasks without responsible"
: "Aufgaben ohne Verantwortlichen"

, "manage shared task lists"
: "Gemeinsame Aufgabenlisten verwalten"

, "Create new shared tasks lists"
: "Neue gemeinse Aufgabenliste anlegen"

, "manage shared tasks favorites"
: "Gemeinsame Aufgaben-Favoriten verwalten"

, "Create or update shared tasks favorites"
: "Gemeinsame Aufgaben-Favoriten erstellen oder bearbeiten"

, "Status"
: "Status"

, "Do you really want to delete the selected task?"
: "Wollen Sie die ausgewählte Aufgabe wirklich löschen?"

, "Task"
: "Aufgabe"

, "to do list"
: "Aufgabenliste"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
